@@ -4,10 +4,12 @@ from classytags.parser import Parser
 from django import template
 from django.conf import settings
 from django.utils.importlib import import_module
+
 from sekizai.helpers import get_varname
 
 register = template.Library()
 
+
 def validate_context(context):
     """
     Validates a given context.
@@ -30,6 +32,7 @@ def validate_context(context):
         "render your templates."
     )
 
+
 def import_processor(import_path):
     if '.' not in import_path:
         raise TypeError("Import paths must contain at least one '.'")
@@ -129,13 +132,18 @@ class Addtoblock(SekizaiTag):
     options = Options(
         Argument('name'),
         Flag('strip', default=False, true_values=['strip']),
+        'preprocessor',
+        Argument('preprocessor', required=False, default=None, resolve=False),
         parser_class=AddtoblockParser,
     )
     
-    def render_tag(self, context, name, strip, nodelist):
+    def render_tag(self, context, name, strip, preprocessor, nodelist):
         rendered_contents = nodelist.render(context)
         if strip:
             rendered_contents = rendered_contents.strip()
+        if preprocessor:
+            func = import_processor(preprocessor)
+            rendered_contents = func(context, rendered_contents, name)
         varname = get_varname()
         context[varname][name].append(rendered_contents)
         return ""
